@@ -8,10 +8,6 @@ from dda.cli.base import dynamic_group
 
 @dynamic_group(
     short_help="Manage dda's dependencies",
-    subcommands=(
-        "lock",
-        "sync",
-    ),
 )
 def cmd() -> None:
     pass
