@@ -5,18 +5,16 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING
 
-import click
-
-from dda.cli.base import dynamic_command
+from dda.cli.base import dynamic_command, pass_app
 
 if TYPE_CHECKING:
     from dda.cli.application import Application
 
 
 @dynamic_command(short_help="Clear the log")
-@click.pass_obj
+@pass_app
 def cmd(app: Application) -> None:
     """
     Clear the log.
     """
-    app.display(app.telemetry.read_log())
+    app.telemetry.clear_log()
