@@ -11,6 +11,7 @@ from subprocess import CompletedProcess
 import msgspec
 import pytest
 
+from dda.config.constants import AppEnvVars
 from dda.env.dev.types.linux_container import LinuxContainer
 from dda.utils.fs import Path
 
@@ -33,10 +34,46 @@ def get_starship_mount(shared_dir: Path) -> list[str]:
     return ["-v", f"{shared_dir / 'shell' / 'starship.toml'}:/root/.shared/shell/starship.toml"]
 
 
+def get_cache_volumes() -> list[str]:
+    return [
+        "--mount",
+        "type=volume,src=dda-env-dev-linux-container-go_build_cache,dst=/root/.cache/go-build",
+        "--mount",
+        "type=volume,src=dda-env-dev-linux-container-go_mod_cache,dst=/go/pkg/mod",
+        "--mount",
+        "type=volume,src=dda-env-dev-linux-container-pip_cache,dst=/root/.cache/pip",
+        "--mount",
+        "type=volume,src=dda-env-dev-linux-container-cargo_registry,dst=/root/.cargo/registry",
+        "--mount",
+        "type=volume,src=dda-env-dev-linux-container-cargo_git,dst=/root/.cargo/git",
+        "--mount",
+        "type=volume,src=dda-env-dev-linux-container-omnibus_gems,dst=/omnibus/vendor/bundle",
+        "--mount",
+        "type=volume,src=dda-env-dev-linux-container-omnibus_cache,dst=/omnibus/cache",
+        "--mount",
+        "type=volume,src=dda-env-dev-linux-container-omnibus_git_cache,dst=/tmp/omnibus-git-cache",
+        "--mount",
+        "type=volume,src=dda-env-dev-linux-container-vscode_extensions,dst=/root/.vscode-extensions",
+    ]
+
+
+def assert_ssh_config_written(method, hostname):
+    method.assert_called_once_with(
+        hostname,
+        {
+            "StrictHostKeyChecking": "no",
+            "ForwardAgent": "yes",
+            "UserKnownHostsFile": "/dev/null",
+            "SetEnv": ["TERM=xterm-256color"],
+        },
+    )
+
+
 def test_default_config(app):
     container = LinuxContainer(app=app, name="linux-container", instance="default")
 
     assert msgspec.to_builtins(container.config) == {
+        "arch": None,
         "cli": "docker",
         "clone": False,
         "image": "datadog/agent-dev-env-linux",
@@ -138,21 +175,15 @@ class TestStart:
             """
         )
 
-        write_server_config.assert_called_once_with(
-            "localhost",
-            {
-                "StrictHostKeyChecking": "no",
-                "ForwardAgent": "yes",
-                "UserKnownHostsFile": "/dev/null",
-            },
-        )
+        assert_ssh_config_written(write_server_config, "localhost")
 
         shared_dir = temp_dir / "data" / "env" / "dev" / "linux-container" / ".shared"
         starship_mount = get_starship_mount(shared_dir)
+        cache_volumes = get_cache_volumes()
         assert calls == [
             (
                 ([helpers.locate("docker"), "pull", "datadog/agent-dev-env-linux"],),
-                {"encoding": "utf-8", "stdout": subprocess.PIPE, "stderr": subprocess.STDOUT},
+                {"encoding": "utf-8", "stdout": subprocess.PIPE, "stderr": subprocess.STDOUT, "env": mocker.ANY},
             ),
             (
                 (
@@ -166,17 +197,26 @@ class TestStart:
                         "dda-linux-container-default",
                         "-p",
                         "59730:22",
+                        "-v",
+                        "/var/run/docker.sock:/var/run/docker.sock",
                         "-e",
-                        "DD_SHELL=zsh",
+                        "DD_SHELL",
+                        "-e",
+                        AppEnvVars.TELEMETRY_API_KEY,
+                        "-e",
+                        "GIT_AUTHOR_NAME",
+                        "-e",
+                        "GIT_AUTHOR_EMAIL",
                         *starship_mount,
                         "-v",
                         f"{shared_dir / 'shell' / 'zsh' / '.zsh_history'}:/root/.shared/shell/zsh/.zsh_history",
+                        *cache_volumes,
                         "-v",
                         f"{repo_dir}:/root/repos/datadog-agent",
                         "datadog/agent-dev-env-linux",
                     ],
                 ),
-                {"encoding": "utf-8", "stdout": subprocess.PIPE, "stderr": subprocess.STDOUT},
+                {"encoding": "utf-8", "stdout": subprocess.PIPE, "stderr": subprocess.STDOUT, "env": mocker.ANY},
             ),
         ]
 
@@ -208,21 +248,15 @@ class TestStart:
             """
         )
 
-        write_server_config.assert_called_once_with(
-            "localhost",
-            {
-                "StrictHostKeyChecking": "no",
-                "ForwardAgent": "yes",
-                "UserKnownHostsFile": "/dev/null",
-            },
-        )
+        assert_ssh_config_written(write_server_config, "localhost")
 
         shared_dir = temp_dir / "data" / "env" / "dev" / "linux-container" / ".shared"
         starship_mount = get_starship_mount(shared_dir)
+        cache_volumes = get_cache_volumes()
         assert calls == [
             (
                 ([helpers.locate("docker"), "pull", "datadog/agent-dev-env-linux"],),
-                {"encoding": "utf-8", "stdout": subprocess.PIPE, "stderr": subprocess.STDOUT},
+                {"encoding": "utf-8", "stdout": subprocess.PIPE, "stderr": subprocess.STDOUT, "env": mocker.ANY},
             ),
             (
                 (
@@ -236,15 +270,24 @@ class TestStart:
                         "dda-linux-container-default",
                         "-p",
                         "59730:22",
+                        "-v",
+                        "/var/run/docker.sock:/var/run/docker.sock",
                         "-e",
-                        "DD_SHELL=zsh",
+                        "DD_SHELL",
+                        "-e",
+                        AppEnvVars.TELEMETRY_API_KEY,
+                        "-e",
+                        "GIT_AUTHOR_NAME",
+                        "-e",
+                        "GIT_AUTHOR_EMAIL",
                         *starship_mount,
                         "-v",
                         f"{shared_dir / 'shell' / 'zsh' / '.zsh_history'}:/root/.shared/shell/zsh/.zsh_history",
+                        *cache_volumes,
                         "datadog/agent-dev-env-linux",
                     ],
                 ),
-                {"encoding": "utf-8", "stdout": subprocess.PIPE, "stderr": subprocess.STDOUT},
+                {"encoding": "utf-8", "stdout": subprocess.PIPE, "stderr": subprocess.STDOUT, "env": mocker.ANY},
             ),
             (
                 (
@@ -296,17 +339,11 @@ class TestStart:
             """
         )
 
-        write_server_config.assert_called_once_with(
-            "localhost",
-            {
-                "StrictHostKeyChecking": "no",
-                "ForwardAgent": "yes",
-                "UserKnownHostsFile": "/dev/null",
-            },
-        )
+        assert_ssh_config_written(write_server_config, "localhost")
 
         shared_dir = temp_dir / "data" / "env" / "dev" / "linux-container" / ".shared"
         starship_mount = get_starship_mount(shared_dir)
+        cache_volumes = get_cache_volumes()
         assert calls == [
             (
                 (
@@ -320,17 +357,26 @@ class TestStart:
                         "dda-linux-container-default",
                         "-p",
                         "59730:22",
+                        "-v",
+                        "/var/run/docker.sock:/var/run/docker.sock",
                         "-e",
-                        "DD_SHELL=zsh",
+                        "DD_SHELL",
+                        "-e",
+                        AppEnvVars.TELEMETRY_API_KEY,
+                        "-e",
+                        "GIT_AUTHOR_NAME",
+                        "-e",
+                        "GIT_AUTHOR_EMAIL",
                         *starship_mount,
                         "-v",
                         f"{shared_dir / 'shell' / 'zsh' / '.zsh_history'}:/root/.shared/shell/zsh/.zsh_history",
+                        *cache_volumes,
                         "-v",
                         f"{repo_dir}:/root/repos/datadog-agent",
                         "datadog/agent-dev-env-linux",
                     ],
                 ),
-                {"encoding": "utf-8", "stdout": subprocess.PIPE, "stderr": subprocess.STDOUT},
+                {"encoding": "utf-8", "stdout": subprocess.PIPE, "stderr": subprocess.STDOUT, "env": mocker.ANY},
             ),
         ]
 
@@ -370,21 +416,15 @@ class TestStart:
             """
         )
 
-        write_server_config.assert_called_once_with(
-            "localhost",
-            {
-                "StrictHostKeyChecking": "no",
-                "ForwardAgent": "yes",
-                "UserKnownHostsFile": "/dev/null",
-            },
-        )
+        assert_ssh_config_written(write_server_config, "localhost")
 
         shared_dir = temp_dir / "data" / "env" / "dev" / "linux-container" / ".shared"
         starship_mount = get_starship_mount(shared_dir)
+        cache_volumes = get_cache_volumes()
         assert calls == [
             (
                 ([helpers.locate("docker"), "pull", "datadog/agent-dev-env-linux"],),
-                {"encoding": "utf-8", "stdout": subprocess.PIPE, "stderr": subprocess.STDOUT},
+                {"encoding": "utf-8", "stdout": subprocess.PIPE, "stderr": subprocess.STDOUT, "env": mocker.ANY},
             ),
             (
                 (
@@ -398,11 +438,20 @@ class TestStart:
                         "dda-linux-container-default",
                         "-p",
                         "59730:22",
+                        "-v",
+                        "/var/run/docker.sock:/var/run/docker.sock",
                         "-e",
-                        "DD_SHELL=zsh",
+                        "DD_SHELL",
+                        "-e",
+                        AppEnvVars.TELEMETRY_API_KEY,
+                        "-e",
+                        "GIT_AUTHOR_NAME",
+                        "-e",
+                        "GIT_AUTHOR_EMAIL",
                         *starship_mount,
                         "-v",
                         f"{shared_dir / 'shell' / 'zsh' / '.zsh_history'}:/root/.shared/shell/zsh/.zsh_history",
+                        *cache_volumes,
                         "-v",
                         f"{repo1_dir}:/root/repos/datadog-agent",
                         "-v",
@@ -410,7 +459,7 @@ class TestStart:
                         "datadog/agent-dev-env-linux",
                     ],
                 ),
-                {"encoding": "utf-8", "stdout": subprocess.PIPE, "stderr": subprocess.STDOUT},
+                {"encoding": "utf-8", "stdout": subprocess.PIPE, "stderr": subprocess.STDOUT, "env": mocker.ANY},
             ),
         ]
 
@@ -443,21 +492,15 @@ class TestStart:
             """
         )
 
-        write_server_config.assert_called_once_with(
-            "localhost",
-            {
-                "StrictHostKeyChecking": "no",
-                "ForwardAgent": "yes",
-                "UserKnownHostsFile": "/dev/null",
-            },
-        )
+        assert_ssh_config_written(write_server_config, "localhost")
 
         shared_dir = temp_dir / "data" / "env" / "dev" / "linux-container" / ".shared"
         starship_mount = get_starship_mount(shared_dir)
+        cache_volumes = get_cache_volumes()
         assert calls == [
             (
                 ([helpers.locate("docker"), "pull", "datadog/agent-dev-env-linux"],),
-                {"encoding": "utf-8", "stdout": subprocess.PIPE, "stderr": subprocess.STDOUT},
+                {"encoding": "utf-8", "stdout": subprocess.PIPE, "stderr": subprocess.STDOUT, "env": mocker.ANY},
             ),
             (
                 (
@@ -471,15 +514,24 @@ class TestStart:
                         "dda-linux-container-default",
                         "-p",
                         "59730:22",
+                        "-v",
+                        "/var/run/docker.sock:/var/run/docker.sock",
                         "-e",
-                        "DD_SHELL=zsh",
+                        "DD_SHELL",
+                        "-e",
+                        AppEnvVars.TELEMETRY_API_KEY,
+                        "-e",
+                        "GIT_AUTHOR_NAME",
+                        "-e",
+                        "GIT_AUTHOR_EMAIL",
                         *starship_mount,
                         "-v",
                         f"{shared_dir / 'shell' / 'zsh' / '.zsh_history'}:/root/.shared/shell/zsh/.zsh_history",
+                        *cache_volumes,
                         "datadog/agent-dev-env-linux",
                     ],
                 ),
-                {"encoding": "utf-8", "stdout": subprocess.PIPE, "stderr": subprocess.STDOUT},
+                {"encoding": "utf-8", "stdout": subprocess.PIPE, "stderr": subprocess.STDOUT, "env": mocker.ANY},
             ),
             (
                 (
@@ -529,7 +581,7 @@ class TestStop:
             """
         )
 
-    def test_default(self, dda, helpers):
+    def test_default(self, dda, helpers, mocker):
         with helpers.hybrid_patch(
             "subprocess.run",
             return_values={
@@ -550,7 +602,7 @@ class TestStop:
         assert calls == [
             (
                 ([helpers.locate("docker"), "stop", "-t", "0", "dda-linux-container-default"],),
-                {"encoding": "utf-8", "stdout": subprocess.PIPE, "stderr": subprocess.STDOUT},
+                {"encoding": "utf-8", "stdout": subprocess.PIPE, "stderr": subprocess.STDOUT, "env": mocker.ANY},
             ),
         ]
 
@@ -568,7 +620,7 @@ class TestRemove:
             """
         )
 
-    def test_default(self, dda, helpers):
+    def test_default(self, dda, helpers, mocker):
         with helpers.hybrid_patch(
             "subprocess.run",
             return_values={
@@ -591,44 +643,47 @@ class TestRemove:
         assert calls == [
             (
                 ([helpers.locate("docker"), "rm", "-f", "dda-linux-container-default"],),
-                {"encoding": "utf-8", "stdout": subprocess.PIPE, "stderr": subprocess.STDOUT},
+                {"encoding": "utf-8", "stdout": subprocess.PIPE, "stderr": subprocess.STDOUT, "env": mocker.ANY},
             ),
         ]
 
 
 class TestShell:
-    def test_default(self, dda, mocker):
-        mocker.patch(
+    def test_default(self, dda, helpers, mocker):
+        with helpers.hybrid_patch(
             "subprocess.run",
-            return_value=CompletedProcess([], returncode=0, stdout=json.dumps([{"State": {"Status": "running"}}])),
-        )
-        write_server_config = mocker.patch("dda.utils.ssh.write_server_config")
-        replace_current_process = mocker.patch("dda.utils.process.SubprocessRunner.replace_current_process")
+            return_values={
+                # Stop command checks the status
+                1: CompletedProcess([], returncode=0, stdout=json.dumps([{"State": {"Status": "running"}}])),
+                # Capture ssh command
+            },
+        ) as calls:
+            write_server_config = mocker.patch("dda.utils.ssh.write_server_config")
 
-        result = dda("env", "dev", "shell")
+            result = dda("env", "dev", "shell")
 
         assert result.exit_code == 0, result.output
         assert not result.output
 
-        write_server_config.assert_called_once_with(
-            "localhost",
-            {
-                "StrictHostKeyChecking": "no",
-                "ForwardAgent": "yes",
-                "UserKnownHostsFile": "/dev/null",
-            },
-        )
-        replace_current_process.assert_called_once_with([
-            "ssh",
-            "-A",
-            "-q",
-            "-t",
-            "-p",
-            "59730",
-            "root@localhost",
-            "--",
-            "cd /root/repos/datadog-agent && zsh -l -i",
-        ])
+        assert_ssh_config_written(write_server_config, "localhost")
+        assert calls == [
+            (
+                (
+                    [
+                        helpers.locate("ssh"),
+                        "-A",
+                        "-q",
+                        "-t",
+                        "-p",
+                        "59730",
+                        "root@localhost",
+                        "--",
+                        "cd /root/repos/datadog-agent && zsh -l -i",
+                    ],
+                ),
+                {},
+            ),
+        ]
 
 
 class TestRun:
@@ -646,46 +701,34 @@ class TestRun:
 
     def test_default(self, dda, helpers, mocker):
         write_server_config = mocker.patch("dda.utils.ssh.write_server_config")
+        run = mocker.patch("dda.utils.process.SubprocessRunner.run")
 
         with helpers.hybrid_patch(
             "subprocess.run",
             return_values={
                 # Stop command checks the status
                 1: CompletedProcess([], returncode=0, stdout=json.dumps([{"State": {"Status": "running"}}])),
-                # Capture command run
             },
-        ) as calls:
+        ):
             result = dda("env", "dev", "run", "echo", "foo")
 
         assert result.exit_code == 0, result.output
         assert not result.output
 
-        write_server_config.assert_called_once_with(
-            "localhost",
-            {
-                "StrictHostKeyChecking": "no",
-                "ForwardAgent": "yes",
-                "UserKnownHostsFile": "/dev/null",
-            },
+        assert_ssh_config_written(write_server_config, "localhost")
+        run.assert_called_once_with(
+            [
+                "ssh",
+                "-A",
+                "-q",
+                "-t",
+                "-p",
+                "59730",
+                "root@localhost",
+                "--",
+                "cd /root/repos/datadog-agent && echo foo",
+            ],
         )
-        assert calls == [
-            (
-                (
-                    [
-                        helpers.locate("ssh"),
-                        "-A",
-                        "-q",
-                        "-t",
-                        "-p",
-                        "59730",
-                        "root@localhost",
-                        "--",
-                        "cd /root/repos/datadog-agent && echo foo",
-                    ],
-                ),
-                {},
-            ),
-        ]
 
 
 class TestCode:
@@ -703,38 +746,197 @@ class TestCode:
 
     def test_default(self, dda, helpers, mocker):
         write_server_config = mocker.patch("dda.utils.ssh.write_server_config")
+        run = mocker.patch("dda.utils.process.SubprocessRunner.run")
 
         with helpers.hybrid_patch(
             "subprocess.run",
             return_values={
                 # Stop command checks the status
                 1: CompletedProcess([], returncode=0, stdout=json.dumps([{"State": {"Status": "running"}}])),
-                # Capture VS Code run
             },
-        ) as calls:
+        ):
             result = dda("env", "dev", "code")
 
         assert result.exit_code == 0, result.output
         assert not result.output
 
-        write_server_config.assert_called_once_with(
-            "localhost",
-            {
-                "StrictHostKeyChecking": "no",
-                "ForwardAgent": "yes",
-                "UserKnownHostsFile": "/dev/null",
-            },
+        assert_ssh_config_written(write_server_config, "localhost")
+        run.assert_called_once_with(
+            [
+                "code",
+                "--remote",
+                "ssh-remote+root@localhost:59730",
+                "/root/repos/datadog-agent",
+            ],
         )
+
+    def test_editor_flag(self, dda, helpers, mocker):
+        write_server_config = mocker.patch("dda.utils.ssh.write_server_config")
+        run = mocker.patch("dda.utils.process.SubprocessRunner.run")
+
+        with helpers.hybrid_patch(
+            "subprocess.run",
+            return_values={
+                # Stop command checks the status
+                1: CompletedProcess([], returncode=0, stdout=json.dumps([{"State": {"Status": "running"}}])),
+            },
+        ):
+            result = dda("env", "dev", "code", "--editor", "cursor")
+
+        assert result.exit_code == 0, result.output
+        assert not result.output
+
+        assert_ssh_config_written(write_server_config, "localhost")
+        run.assert_called_once_with(
+            [
+                "cursor",
+                "--remote",
+                "ssh-remote+root@localhost:59730",
+                "/root/repos/datadog-agent",
+            ],
+        )
+
+    def test_editor_config(self, dda, config_file, helpers, mocker):
+        config_file.data["env"]["dev"]["editor"] = "cursor"
+        config_file.save()
+
+        write_server_config = mocker.patch("dda.utils.ssh.write_server_config")
+        run = mocker.patch("dda.utils.process.SubprocessRunner.run")
+
+        with helpers.hybrid_patch(
+            "subprocess.run",
+            return_values={
+                # Stop command checks the status
+                1: CompletedProcess([], returncode=0, stdout=json.dumps([{"State": {"Status": "running"}}])),
+            },
+        ):
+            result = dda("env", "dev", "code")
+
+        assert result.exit_code == 0, result.output
+        assert not result.output
+
+        assert_ssh_config_written(write_server_config, "localhost")
+        run.assert_called_once_with(
+            [
+                "cursor",
+                "--remote",
+                "ssh-remote+root@localhost:59730",
+                "/root/repos/datadog-agent",
+            ],
+        )
+
+
+class TestRemoveCache:
+    def test_not_stopped(self, dda, helpers):
+        with helpers.hybrid_patch(
+            "subprocess.run",
+            return_values={
+                1: CompletedProcess([], returncode=0, stdout=json.dumps([{"State": {"Status": "running"}}])),
+            },
+        ):
+            result = dda("env", "dev", "cache", "remove")
+
+        assert result.exit_code == 1, result.output
+        assert result.output == helpers.dedent(
+            """
+            Cannot remove cache for developer environment `linux-container` in state `started`, must be one of: nonexistent, stopped
+            """
+        )
+
+    def test_default(self, dda, helpers, mocker):
+        with helpers.hybrid_patch(
+            "subprocess.run",
+            return_values={
+                1: CompletedProcess(
+                    [], returncode=0, stdout=json.dumps([{"State": {"Status": "exited", "ExitCode": 0}}])
+                ),
+                2: CompletedProcess([], returncode=0, stdout="foo\ndda-env-dev-linux-container-go_build_cache\nbar"),
+                # Capture volume removal
+            },
+        ) as calls:
+            result = dda("env", "dev", "cache", "remove")
+
+        assert result.exit_code == 0, result.output
+        assert result.output == helpers.dedent(
+            """
+            Removing cache
+            """
+        )
+
         assert calls == [
             (
-                (
-                    [
-                        helpers.locate("code"),
-                        "--remote",
-                        "ssh-remote+root@localhost:59730",
-                        "/root/repos/datadog-agent",
-                    ],
-                ),
-                {},
+                ([helpers.locate("docker"), "volume", "rm", "dda-env-dev-linux-container-go_build_cache"],),
+                {"encoding": "utf-8", "stdout": subprocess.PIPE, "stderr": subprocess.STDOUT, "env": mocker.ANY},
             ),
         ]
+
+
+class TestCacheSize:
+    def test_default(self, dda, helpers):
+        with helpers.hybrid_patch(
+            "subprocess.run",
+            return_values={
+                1: CompletedProcess(
+                    [],
+                    returncode=0,
+                    stdout="""\
+foo 1TB
+dda-env-dev-linux-container-go_build_cache 512MB
+dda-env-dev-linux-container-go_mod_cache 1GB
+bar 1PB
+""",
+                ),
+            },
+        ):
+            result = dda("env", "dev", "cache", "size")
+
+        assert result.exit_code == 0, result.output
+        assert result.output == helpers.dedent(
+            """
+            Calculating cache size
+            1.50 GiB
+            """
+        )
+
+    def test_empty(self, dda, helpers):
+        with helpers.hybrid_patch(
+            "subprocess.run",
+            return_values={
+                1: CompletedProcess([], returncode=0, stdout="foo 1TB\nbar 1PB"),
+            },
+        ):
+            result = dda("env", "dev", "cache", "size")
+
+        assert result.exit_code == 0, result.output
+        assert result.output == helpers.dedent(
+            """
+            Calculating cache size
+            Empty
+            """
+        )
+
+    def test_bytes(self, dda, helpers):
+        with helpers.hybrid_patch(
+            "subprocess.run",
+            return_values={
+                1: CompletedProcess(
+                    [],
+                    returncode=0,
+                    stdout="""\
+foo 1TB
+dda-env-dev-linux-container-go_build_cache 1000B
+dda-env-dev-linux-container-go_mod_cache 23B
+bar 1PB
+""",
+                ),
+            },
+        ):
+            result = dda("env", "dev", "cache", "size")
+
+        assert result.exit_code == 0, result.output
+        assert result.output == helpers.dedent(
+            """
+            Calculating cache size
+            1023 B
+            """
+        )
